@@ -17,8 +17,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import logging
 log = logging.getLogger(__name__)
 
-from bokeh.util.api import public, internal ; public, internal
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
@@ -41,10 +39,9 @@ from .util import html_page_for_render_items
 #-----------------------------------------------------------------------------
 
 #-----------------------------------------------------------------------------
-# Public API
+# General API
 #-----------------------------------------------------------------------------
 
-@public((1,0,0))
 def server_document(url="default", relative_urls=False, resources="default", arguments=None):
     ''' Return a script tag that embeds content from a Bokeh server.
 
@@ -106,8 +103,7 @@ def server_document(url="default", relative_urls=False, resources="default", arg
 
     return encode_utf8(tag)
 
-@public((1,0,0))
-def server_session(model, session_id, url="default", relative_urls=False, resources="default", arguments=None):
+def server_session(model=None, session_id=None, url="default", relative_urls=False, resources="default", arguments=None):
     ''' Return a script tag that embeds content from a specific existing session on
     a Bokeh server.
 
@@ -121,13 +117,13 @@ def server_session(model, session_id, url="default", relative_urls=False, resour
         function for different or multiple page loads.
 
     Args:
-        model (Model or None) :
-            The object to render from the session, or None.
+        model (Model or None, optional) :
+            The object to render from the session, or None. (default: None)
 
             If None, the entire document will be rendered.
 
         session_id (str) :
-            A server session ID (default: None)
+            A server session ID
 
         url (str, optional) :
             A URL to a Bokeh application on a Bokeh server (default: "default")
@@ -170,6 +166,9 @@ def server_session(model, session_id, url="default", relative_urls=False, resour
             probably not desired.
 
     '''
+    if session_id is None:
+        raise ValueError("Must supply a session_id")
+
     url = _clean_url(url)
 
     app_path = _get_app_path(url)
@@ -194,10 +193,9 @@ def server_session(model, session_id, url="default", relative_urls=False, resour
     return encode_utf8(tag)
 
 #-----------------------------------------------------------------------------
-# Internal API
+# Dev API
 #-----------------------------------------------------------------------------
 
-@internal((1,0,0))
 def server_html_page_for_session(session_id, resources, title, template=FILE, template_variables=None):
     '''
 
