@@ -13,9 +13,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import pytest ; pytest
 
-from bokeh.util.api import INTERNAL, PUBLIC ; INTERNAL, PUBLIC
-from bokeh.util.testing import verify_api ; verify_api
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
@@ -30,27 +27,6 @@ import bs4
 # Module under test
 import bokeh.embed.server as bes
 
-#-----------------------------------------------------------------------------
-# API Definition
-#-----------------------------------------------------------------------------
-
-api = {
-
-    PUBLIC: (
-
-        ( 'server_document', (1, 0, 0) ),
-        ( 'server_session',  (1, 0, 0) ),
-
-    ), INTERNAL: (
-
-        ( 'server_html_page_for_session', (1, 0, 0) ),
-
-    )
-
-}
-
-Test_api = verify_api(bes, api)
-
 #-----------------------------------------------------------------------------
 # Setup
 #-----------------------------------------------------------------------------
@@ -63,7 +39,7 @@ def test_plot():
     return test_plot
 
 #-----------------------------------------------------------------------------
-# Public API
+# General API
 #-----------------------------------------------------------------------------
 
 class TestServerDocument(object):
@@ -251,7 +227,7 @@ class TestServerSession(object):
                           'src' : src }
 
 #-----------------------------------------------------------------------------
-# Internal API
+# Dev API
 #-----------------------------------------------------------------------------
 
 #-----------------------------------------------------------------------------
