@@ -13,9 +13,6 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import pytest ; pytest
 
-from bokeh.util.api import INTERNAL, PUBLIC ; INTERNAL, PUBLIC
-from bokeh.util.testing import verify_api ; verify_api
-
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
@@ -40,26 +37,6 @@ from bokeh.util.string import encode_utf8
 # Module under test
 import bokeh.embed.standalone as bes
 
-#-----------------------------------------------------------------------------
-# API Definition
-#-----------------------------------------------------------------------------
-
-api = {
-
-    PUBLIC: (
-
-        ( 'autoload_static', (1,0,0) ),
-        ( 'components',      (1,0,0) ),
-        ( 'file_html',       (1,0,0) ),
-
-    ), INTERNAL: (
-
-    )
-
-}
-
-Test_api = verify_api(bes, api)
-
 #-----------------------------------------------------------------------------
 # Setup
 #-----------------------------------------------------------------------------
@@ -78,7 +55,7 @@ def test_plot():
     return test_plot
 
 #-----------------------------------------------------------------------------
-# Public API
+# General API
 #-----------------------------------------------------------------------------
 
 class Test_autoload_static(object):
@@ -260,8 +237,25 @@ class Test_file_html(object):
         r = bes.file_html(test_plot, CDN, "&<")
         assert "<title>&amp;&lt;</title>" in r
 
+    def test_entire_doc_is_used(self):
+        from bokeh.document import Document
+        from bokeh.models import Button
+
+        fig = figure()
+        fig.x([0], [0])
+
+        button = Button(label="Button")
+
+        d = Document()
+        d.add_root(fig)
+        d.add_root(button)
+        out = bes.file_html([fig], CDN)
+
+        # this is a very coarse test but it will do
+        assert "bokeh-widgets" in out
+
 #-----------------------------------------------------------------------------
-# Internal API
+# Dev API
 #-----------------------------------------------------------------------------
 
 #-----------------------------------------------------------------------------
