@@ -8,12 +8,10 @@
 from __future__ import absolute_import
 
 from .core.enums import Location, SizingMode
-from .models.tools import ToolbarBox
+from .models.tools import ProxyToolbar, ToolbarBox
 from .models.plots import Plot
 from .models.layouts import LayoutDOM, Row, Column, Spacer, WidgetBox
 from .models.widgets import Widget
-from .util._plot_arg_helpers import _convert_responsive
-
 
 #-----------------------------------------------------------------------------
 # Common helper functions
@@ -60,10 +58,6 @@ def row(*args, **kwargs):
             modes see :attr:`~bokeh.models.layouts.LayoutDOM.sizing_mode`
             description on :class:`~bokeh.models.layouts.LayoutDOM`.
 
-        responsive (``True``, ``False``): True sets ``sizing_mode`` to
-            ``"width_ar"``. ``False`` sets sizing_mode to ``"fixed"``. Using
-            responsive will override sizing_mode.
-
     Returns:
         Row: A row of LayoutDOM objects all with the same sizing_mode.
 
@@ -73,12 +67,9 @@ def row(*args, **kwargs):
         >>> row(children=[widget_box_1, plot_1], sizing_mode='stretch_both')
     """
 
-    responsive = kwargs.pop('responsive', None)
     sizing_mode = kwargs.pop('sizing_mode', 'fixed')
     children = kwargs.pop('children', None)
 
-    if responsive:
-        sizing_mode = _convert_responsive(responsive)
     _verify_sizing_mode(sizing_mode)
     children = _handle_children(*args, children=children)
 
@@ -114,10 +105,6 @@ def column(*args, **kwargs):
             modes see :attr:`~bokeh.models.layouts.LayoutDOM.sizing_mode`
             description on :class:`~bokeh.models.layouts.LayoutDOM`.
 
-        responsive (``True``, ``False``): True sets ``sizing_mode`` to
-            ``"width_ar"``. ``False`` sets sizing_mode to ``"fixed"``. Using
-            responsive will override sizing_mode.
-
     Returns:
         Column: A column of LayoutDOM objects all with the same sizing_mode.
 
@@ -127,12 +114,9 @@ def column(*args, **kwargs):
         >>> column(children=[widget_box_1, plot_1], sizing_mode='stretch_both')
     """
 
-    responsive = kwargs.pop('responsive', None)
     sizing_mode = kwargs.pop('sizing_mode', 'fixed')
     children = kwargs.pop('children', None)
 
-    if responsive:
-        sizing_mode = _convert_responsive(responsive)
     _verify_sizing_mode(sizing_mode)
     children = _handle_children(*args, children=children)
 
@@ -163,10 +147,6 @@ def widgetbox(*args, **kwargs):
             modes see :attr:`~bokeh.models.layouts.LayoutDOM.sizing_mode`
             description on :class:`~bokeh.models.layouts.LayoutDOM`.
 
-        responsive (``True``, ``False``): True sets ``sizing_mode`` to
-            ``"width_ar"``. ``False`` sets sizing_mode to ``"fixed"``. Using
-            responsive will override sizing_mode.
-
     Returns:
         WidgetBox: A WidgetBox of Widget instances all with the same sizing_mode.
 
@@ -176,12 +156,9 @@ def widgetbox(*args, **kwargs):
         >>> widgetbox(children=[slider], sizing_mode='scale_width')
     """
 
-    responsive = kwargs.pop('responsive', None)
     sizing_mode = kwargs.pop('sizing_mode', 'fixed')
     children = kwargs.pop('children', None)
 
-    if responsive:
-        sizing_mode = _convert_responsive(responsive)
     _verify_sizing_mode(sizing_mode)
     children = _handle_children(*args, children=children)
 
@@ -218,10 +195,6 @@ def layout(*args, **kwargs):
             modes see :attr:`~bokeh.models.layouts.LayoutDOM.sizing_mode`
             description on :class:`~bokeh.models.layouts.LayoutDOM`.
 
-        responsive (``True``, ``False``): True sets ``sizing_mode`` to
-            ``"width_ar"``. ``False`` sets sizing_mode to ``"fixed"``. Using
-            responsive will override sizing_mode.
-
     Returns:
         Column: A column of ``Row`` layouts of the children, all with the same sizing_mode.
 
@@ -238,12 +211,9 @@ def layout(*args, **kwargs):
             )
 
     """
-    responsive = kwargs.pop('responsive', None)
     sizing_mode = kwargs.pop('sizing_mode', 'fixed')
     children = kwargs.pop('children', None)
 
-    if responsive:
-        sizing_mode = _convert_responsive(responsive)
     _verify_sizing_mode(sizing_mode)
     children = _handle_children(*args, children=children)
 
@@ -305,10 +275,6 @@ def gridplot(*args, **kwargs):
             You must only pass an un-nested list of plots (as opposed to a list of lists of plots)
             when using ncols.
 
-        responsive (``True``, ``False``): True sets ``sizing_mode`` to
-            ``"width_ar"``. ``False`` sets sizing_mode to ``"fixed"``. Using
-            responsive will override sizing_mode.
-
         plot_width (int, optional): The width you would like all your plots to be
 
         plot_height (int, optional): The height you would like all your plots to be.
@@ -341,16 +307,13 @@ def gridplot(*args, **kwargs):
     toolbar_location = kwargs.get('toolbar_location', 'above')
     sizing_mode = kwargs.get('sizing_mode', 'fixed')
     children = kwargs.get('children')
-    responsive = kwargs.get('responsive')
-    toolbar_options = kwargs.get('toolbar_options')
+    toolbar_options = kwargs.get('toolbar_options', {})
     plot_width = kwargs.get('plot_width')
     plot_height = kwargs.get('plot_height')
     ncols = kwargs.get('ncols')
     merge_tools = kwargs.get('merge_tools', True)
 
     # Integrity checks & set-up
-    if responsive:
-        sizing_mode = _convert_responsive(responsive)
     _verify_sizing_mode(sizing_mode)
 
     if toolbar_location:
@@ -381,10 +344,13 @@ def gridplot(*args, **kwargs):
                         row_tools = row_tools + plot.toolbar.tools
                         plot.toolbar_location = None
             if item is None:
+                width, height = 0, 0
                 for neighbor in row:
                     if isinstance(neighbor, Plot):
+                        width = neighbor.plot_width
+                        height = neighbor.plot_height
                         break
-                item = Spacer(width=neighbor.plot_width, height=neighbor.plot_height)
+                item = Spacer(width=width, height=height)
             if isinstance(item, LayoutDOM):
                 item.sizing_mode = sizing_mode
                 if isinstance(item, Plot):
@@ -403,26 +369,10 @@ def gridplot(*args, **kwargs):
     if not merge_tools:
         return grid
 
-    # Make the toolbar
     if toolbar_location:
-        if not toolbar_options:
-            toolbar_options = {}
-        if 'toolbar_location' not in toolbar_options:
-            toolbar_options['toolbar_location'] = toolbar_location
+        proxy = ProxyToolbar(tools=tools, **toolbar_options)
+        toolbar = ToolbarBox(toolbar=proxy, toolbar_location=toolbar_location)
 
-        # Fixed sizing mode needs scale_width for the toolbar
-        # for layout to work correctly.
-        if sizing_mode == 'fixed':
-            toolbar_sizing_mode = 'scale_width'
-        else:
-            toolbar_sizing_mode = sizing_mode
-        toolbar = ToolbarBox(
-            tools=tools,
-            sizing_mode=toolbar_sizing_mode,
-            **toolbar_options
-        )
-
-    # Set up children
     if toolbar_location == 'above':
         return Column(children=[toolbar, grid], sizing_mode=sizing_mode)
     elif toolbar_location == 'below':
