@@ -5,7 +5,7 @@ a Bokeh |Document|.
 from __future__ import absolute_import, print_function
 
 import logging
-logger = logging.getLogger(__file__)
+logger = logging.getLogger(__name__)
 
 from json import loads
 from operator import itemgetter
@@ -20,7 +20,6 @@ from .themes import default as default_theme
 from .util.callback_manager import PropertyCallbackManager, EventCallbackManager
 from .util.future import with_metaclass
 from .util.serialization import make_id
-from .util.deprecation import deprecated
 from .events import Event
 
 def collect_models(*input_values):
@@ -89,13 +88,6 @@ def get_class(view_model_name):
     from . import models; models
     from .plotting import Figure; Figure
 
-    # We have to try-except here, because this import will fail if Pandas is
-    # not installed, but in that case bkcharts is not usable anyway
-    # try:
-    #     from bkcharts import Chart; Chart
-    # except RuntimeError:
-    #     pass
-
     d = MetaModel.model_class_reverse_map
     if view_model_name in d:
         return d[view_model_name]
@@ -277,7 +269,8 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
     """)
 
     js_event_callbacks = Dict(String, List(Instance("bokeh.models.callbacks.CustomJS")),
-    help="""A mapping of event names to lists of CustomJS callbacks.
+    help="""
+    A mapping of event names to lists of CustomJS callbacks.
 
     Typically, rather then modifying this property directly, callbacks should be
     added using the ``Model.js_on_event`` method:
@@ -392,15 +385,6 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
         if event in self.properties():
             event = "change:%s" % event
 
-        from bokeh.models.sources import ColumnarDataSource
-        if isinstance(self, ColumnarDataSource):
-            if event == 'stream':
-                deprecated((0, 12, 6), "ColumnarDataSource.js_on_change('stream', ...)", "'streaming'")
-                event = 'streaming'
-            elif event == 'patch':
-                event = 'patching'
-                deprecated((0, 12, 6), "ColumnarDataSource.js_on_change('patch', ...)", "'patching'")
-
         if event not in self.js_property_callbacks:
             self.js_property_callbacks[event] = []
         for callback in callbacks:
@@ -422,11 +406,17 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
 
         Args:
             attr (str) : an attribute name on this object
-            callback (callable) : a callback function to register
+            *callbacks (callable) : callback functions to register
 
         Returns:
             None
 
+        Example:
+
+        .. code-block:: python
+
+            widget.on_change('value', callback1, callback2, ..., callback_n)
+
         '''
         if attr not in self.properties():
             raise ValueError("attempted to add a callback on nonexistent %s.%s property" % (self.__class__.__name__, attr))
@@ -546,7 +536,7 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
         # this may need to be further refined in the future, if the a
         # assumption does not hold for future hinted events (e.g. the hint
         # could specify explicitly whether to do normal invalidation or not)
-        if not hint:
+        if hint is None:
             dirty = { 'count' : 0 }
             def mark_dirty(obj):
                 dirty['count'] += 1
@@ -556,7 +546,7 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
                 if dirty['count'] > 0:
                     self._document._invalidate_all_models()
         # chain up to invoke callbacks
-        super(Model, self).trigger(attr, old, new, hint, setter)
+        super(Model, self).trigger(attr, old, new, hint=hint, setter=setter)
 
     def _attach_document(self, doc):
         ''' Attach a model to a Bokeh |Document|.
@@ -665,7 +655,7 @@ class Model(with_metaclass(MetaModel, HasProps, PropertyCallbackManager, EventCa
 
         return html
 
-    def _repr_pretty(self, p, cycle):
+    def _repr_pretty_(self, p, cycle):
         '''
 
         '''
