@@ -7,12 +7,12 @@ from six import string_types
 
 from ..core.properties import Any, Auto, Either, Enum, Int, Seq, Instance, String
 from ..core.enums import HorizontalLocation, VerticalLocation
-from ..models import Plot, Title, Tool, GraphRenderer
+from ..models import ColumnDataSource, Plot, Title, Tool, GraphRenderer
 from ..models import glyphs, markers
 from ..models.tools import Drag, Inspection, Scroll, Tap
 from ..util.options import Options
 from ..util.string import format_docstring
-from ..util._plot_arg_helpers import _convert_responsive
+from ..transform import linear_cmap
 from .helpers import (
     _get_range, _get_scale, _process_axis_and_grid, _process_tools_arg,
     _glyph_function, _process_active_tools, _stack, _graph)
@@ -75,11 +75,11 @@ class FigureOptions(Options):
     Which tap tool should initially be active.
     """)
 
-    x_axis_type = Either(Auto, Enum("linear", "log", "datetime"), default="auto", help="""
+    x_axis_type = Either(Auto, Enum("linear", "log", "datetime", "mercator"), default="auto", help="""
     The type of the x-axis.
     """)
 
-    y_axis_type = Either(Auto, Enum("linear", "log", "datetime"), default="auto", help="""
+    y_axis_type = Either(Auto, Enum("linear", "log", "datetime", "mercator"), default="auto", help="""
     The type of the y-axis.
     """)
 
@@ -96,9 +96,13 @@ class Figure(Plot):
 {glyph_methods}
 
     There are also two specialized methods for stacking bars:
-    :func:`~bokeh.plotting.figure.Figure.hbar_stack` and
-    :func:`~bokeh.plotting.figure.Figure.vbar_stack`
 
+    * :func:`~bokeh.plotting.figure.Figure.hbar_stack`
+    * :func:`~bokeh.plotting.figure.Figure.vbar_stack`
+
+    And one specialized method for making simple hexbin plots:
+
+    * :func:`~bokeh.plotting.figure.Figure.hexbin`
 
     In addition to all the Bokeh model property attributes documented below,
     the ``Figure`` initializer also accepts the following options, which can
@@ -123,12 +127,6 @@ class Figure(Plot):
         if 'width' in kw:
             kw['plot_width'] = kw.pop('width')
 
-        if 'responsive' in kw and 'sizing_mode' in kw:
-            raise ValueError("Figure called with both 'responsive' and 'sizing_mode' supplied, supply only one")
-        if 'responsive' in kw:
-            kw['sizing_mode'] = _convert_responsive(kw['responsive'])
-            del kw['responsive']
-
         opts = FigureOptions(kw)
 
         title = kw.get("title", None)
@@ -314,6 +312,36 @@ Examples:
 
         show(plot)
 
+""")
+
+    hex = _glyph_function(markers.Hex, """
+Examples:
+
+    .. bokeh-plot::
+        :source-position: above
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(plot_width=300, plot_height=300)
+        plot.hex(x=[1, 2, 3], y=[1, 2, 3], size=[10,20,30], color="#74ADD1")
+
+        show(plot)
+
+""")
+
+    hex_tile = _glyph_function(glyphs.HexTile, """
+Examples:
+
+    .. bokeh-plot::
+        :source-position: above
+
+        from bokeh.plotting import figure, output_file, show
+
+        plot = figure(plot_width=300, plot_height=300, match_aspect=True)
+        plot.hex_tile(r=[0, 0, 1], q=[1, 2, 2], fill_color="#74ADD1")
+
+        show(plot)
+
 """)
 
     image = _glyph_function(glyphs.Image, """
@@ -676,6 +704,117 @@ Examples:
 
         return getattr(self, markertype)(*args, **kwargs)
 
+    def hexbin(self, x, y, size, orientation="pointytop", palette="Viridis256", line_color=None, fill_color=None, aspect_scale=1, **kwargs):
+        ''' Perform a simple equal-weight hexagonal binning.
+
+        A :class:`~bokeh.models.glyphs.HexTile` glyph will be added to display
+        the binning. The :class:`~bokeh.models.sources.ColumnDataSource` for
+        the glyph will have columns ``q``, ``r``, and ``count``, where ``q``
+        and ``r`` are `axial coordinates`_ for a tile, and ``count`` is the
+        associated bin count.
+
+        It is often useful to set ``match_aspect=True`` on the associated plot,
+        so that hexagonal tiles are all regular (i.e. not "stretched") in
+        screen space.
+
+        For more sophisicated use-cases, e.g. weighted binning or individually
+        scaling hex tiles, use :func:`hex_tile` directly, or consider a higher
+        level library such as HoloViews.
+
+        Args:
+            x (array[float]) :
+                A NumPy array of x-coordinates to bin into haxagonal tiles.
+
+            y (array[float]) :
+                A NumPy array of y-coordinates to bin into haxagonal tiles
+
+            size (float) :
+                The size of the hexagonal tiling to use. The size is defined as
+                distance from the center of a hexagon to a corner.
+
+                In case the apsect scaling is not 1-1, then specifically `size`
+                is the distance from the center to the "top" corner with the
+                `"pointytop"` orientation, and the distance from the center to
+                a "side" corner with the "flattop" orientation.
+
+            orientation ("pointytop" or "flattop", optional) :
+                Whether the hexagonal tiles should be oriented with a pointed
+                corner on top, or a flat side on top. (default: "pointytop")
+
+            palette (str or seq[color], optional) :
+                A palette (or palette name) to use to colormap the bins according
+                to count. (default: 'Viridis256')
+
+                If ``fill_color`` is supplied, it overrides this value.
+
+            line_color (color, optional) :
+                The outline color for hex tiles, or None (default: None)
+
+            fill_color (color, optional) :
+                An optional fill color for hex tiles, or None. If None, then
+                the ``palette`` will be used to color map the tiles by
+                count. (default: None)
+
+            aspect_scale (float) :
+                Match a plot's aspect ratio scaling.
+
+                When working with a plot with ``aspect_scale != 1``, this
+                parameter can be set to match the plot, in order to draw
+                regular hexagons (insted of "stretched" ones).
+
+                This is roughly equivalent to binning in "screen space", and
+                it may be better to use axis-aligned rectangular bins when
+                plot aspect scales are not one.
+
+        Any additional keyword arguments are passed to :func:`hex_tile`.
+
+        Returns
+            (Glyphrender, DataFrame)
+                A tuple with the ``HexTile`` renderer generated to display the
+                binning, and a Pandas DataFrame with columns ``q``, ``r``,
+                and ``count``, where ``q`` and ``r`` are `axial coordinates`_
+                for a tile, and ``count`` is the associated bin count.
+
+        Example:
+
+            .. bokeh-plot::
+                :source-position: above
+
+                import numpy as np
+                from bokeh.models import HoverTool
+                from bokeh.plotting import figure, show
+
+                x = 2 + 2*np.random.standard_normal(500)
+                y = 2 + 2*np.random.standard_normal(500)
+
+                p = figure(match_aspect=True, tools="wheel_zoom,reset")
+                p.background_fill_color = '#440154'
+                p.grid.visible = False
+
+                p.hexbin(x, y, size=0.5, hover_color="pink", hover_alpha=0.8)
+
+                hover = HoverTool(tooltips=[("count", "@c"), ("(q,r)", "(@q, @r)")])
+                p.add_tools(hover)
+
+                show(p)
+
+        .. _axial coordinates: https://www.redblobgames.com/grids/hexagons/#coordinates-axial
+
+        '''
+        from ..util.hex import hexbin
+
+        bins = hexbin(x, y, size, orientation, aspect_scale=aspect_scale)
+
+        if fill_color is None:
+            fill_color = linear_cmap('c', palette, 0, max(bins.counts))
+
+        source = ColumnDataSource(data=dict(q=bins.q, r=bins.r, c=bins.counts))
+
+        r = self.hex_tile(q="q", r="r", size=size, orientation=orientation, aspect_scale=aspect_scale,
+                          source=source, line_color=line_color, fill_color=fill_color, **kwargs)
+
+        return (r, bins)
+
     def hbar_stack(self, stackers, **kw):
         ''' Generate multiple ``HBar`` renderers for levels stacked left to right.
 
@@ -687,6 +826,9 @@ Examples:
         If a keyword value is a list or tuple, then each call will get one
         value from the sequence.
 
+        Returns:
+            list[GlyphRenderer]
+
         Examples:
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
@@ -705,8 +847,10 @@ Examples:
                 p.hbar(bottom=stack('2016'), top=stack('2016', '2017'), x=10, width=0.9, color='red', source=source)
 
         '''
+        result = []
         for kw in _stack(stackers, "left", "right", **kw):
-            self.hbar(**kw)
+            result.append(self.hbar(**kw))
+        return result
 
     def vbar_stack(self, stackers, **kw):
         ''' Generate multiple ``VBar`` renderers for levels stacked bottom
@@ -720,10 +864,13 @@ Examples:
         If a keyword value is a list or tuple, then each call will get one
         value from the sequence.
 
+        Returns:
+            list[GlyphRenderer]
+
         Examples:
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
-            *2106* and *2017*, then the following call to ``vbar_stack`` will
+            *2016* and *2017*, then the following call to ``vbar_stack`` will
             will create two ``VBar`` renderers that stack:
 
             .. code-block:: python
@@ -739,8 +886,10 @@ Examples:
 
 
         '''
+        result = []
         for kw in _stack(stackers, "bottom", "top", **kw):
-            self.vbar(**kw)
+            result.append(self.vbar(**kw))
+        return result
 
     def graph(self, node_source, edge_source, layout_provider, **kwargs):
         ''' Creates a network graph using the given node, edge and layout provider.
@@ -775,8 +924,13 @@ def figure(**kwargs):
 {glyph_methods}
 
     There are also two specialized methods for stacking bars:
-    :func:`~bokeh.plotting.figure.Figure.hbar_stack` and
-    :func:`~bokeh.plotting.figure.Figure.vbar_stack`
+
+    * :func:`~bokeh.plotting.figure.Figure.hbar_stack`
+    * :func:`~bokeh.plotting.figure.Figure.vbar_stack`
+
+    And one specialized method for making simple hexbin plots:
+
+    * :func:`~bokeh.plotting.figure.Figure.hexbin`
 
     In addition to the standard :class:`~bokeh.plotting.figure.Figure`
     property values (e.g. ``plot_width`` or ``sizing_mode``) the following
@@ -801,6 +955,7 @@ _marker_types = [
     "cross",
     "diamond",
     "diamond_cross",
+    "hex",
     "inverted_triangle",
     "square",
     "square_x",
